# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/secret_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from h2o_secure_store.gen.ai.h2o.securestore.v1 import secret_pb2 as ai_dot_h2o_dot_securestore_dot_v1_dot_secret__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ai/h2o/securestore/v1/secret_service.proto\x12\x15\x61i.h2o.securestore.v1\x1a\"ai/h2o/securestore/v1/secret.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/resource.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\"\xb1\x01\n\x13\x43reateSecretRequest\x12:\n\x06parent\x18\x01 \x01(\tB\"\xe2\x41\x01\x02\xfa\x41\x1b\x12\x19securestore.h2o.ai/SecretR\x06parent\x12;\n\x06secret\x18\x02 \x01(\x0b\x32\x1d.ai.h2o.securestore.v1.SecretB\x04\xe2\x41\x01\x02R\x06secret\x12!\n\tsecret_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\x08secretId\"M\n\x14\x43reateSecretResponse\x12\x35\n\x06secret\x18\x01 \x01(\x0b\x32\x1d.ai.h2o.securestore.v1.SecretR\x06secret\"J\n\x10GetSecretRequest\x12\x36\n\x04name\x18\x01 \x01(\tB\"\xe2\x41\x01\x02\xfa\x41\x1b\n\x19securestore.h2o.ai/SecretR\x04name\"J\n\x11GetSecretResponse\x12\x35\n\x06secret\x18\x01 \x01(\x0b\x32\x1d.ai.h2o.securestore.v1.SecretR\x06secret\"\xc1\x01\n\x12ListSecretsRequest\x12:\n\x06parent\x18\x01 \x01(\tB\"\xe2\x41\x01\x02\xfa\x41\x1b\x12\x19securestore.h2o.ai/SecretR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\x12\'\n\x0cshow_deleted\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0bshowDeleted\"\x95\x01\n\x13ListSecretsResponse\x12\x37\n\x07secrets\x18\x01 \x03(\x0b\x32\x1d.ai.h2o.securestore.v1.SecretR\x07secrets\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"M\n\x13\x44\x65leteSecretRequest\x12\x36\n\x04name\x18\x01 \x01(\tB\"\xe2\x41\x01\x02\xfa\x41\x1b\n\x19securestore.h2o.ai/SecretR\x04name\"M\n\x14\x44\x65leteSecretResponse\x12\x35\n\x06secret\x18\x01 \x01(\x0b\x32\x1d.ai.h2o.securestore.v1.SecretR\x06secret\"O\n\x15UndeleteSecretRequest\x12\x36\n\x04name\x18\x01 \x01(\tB\"\xe2\x41\x01\x02\xfa\x41\x1b\n\x19securestore.h2o.ai/SecretR\x04name\"O\n\x16UndeleteSecretResponse\x12\x35\n\x06secret\x18\x01 \x01(\x0b\x32\x1d.ai.h2o.securestore.v1.SecretR\x06secret2\xb7\x06\n\rSecretService\x12\xb4\x01\n\x0c\x43reateSecret\x12*.ai.h2o.securestore.v1.CreateSecretRequest\x1a+.ai.h2o.securestore.v1.CreateSecretResponse\"K\xda\x41\x17parent,secret,secret_id\x82\xd3\xe4\x93\x02+\"!/v1/{parent=workspaces/*}/secrets:\x06secret\x12\x90\x01\n\tGetSecret\x12\'.ai.h2o.securestore.v1.GetSecretRequest\x1a(.ai.h2o.securestore.v1.GetSecretResponse\"0\xda\x41\x04name\x82\xd3\xe4\x93\x02#\x12!/v1/{name=workspaces/*/secrets/*}\x12\x98\x01\n\x0bListSecrets\x12).ai.h2o.securestore.v1.ListSecretsRequest\x1a*.ai.h2o.securestore.v1.ListSecretsResponse\"2\xda\x41\x06parent\x82\xd3\xe4\x93\x02#\x12!/v1/{parent=workspaces/*}/secrets\x12\x99\x01\n\x0c\x44\x65leteSecret\x12*.ai.h2o.securestore.v1.DeleteSecretRequest\x1a+.ai.h2o.securestore.v1.DeleteSecretResponse\"0\xda\x41\x04name\x82\xd3\xe4\x93\x02#*!/v1/{name=workspaces/*/secrets/*}\x12\xa4\x01\n\x0eUndeleteSecret\x12,.ai.h2o.securestore.v1.UndeleteSecretRequest\x1a-.ai.h2o.securestore.v1.UndeleteSecretResponse\"5\x82\xd3\xe4\x93\x02/\"*/v1/{name=workspaces/*/secrets/*}:undelete:\x01*B\xed\x01\n\x19\x63om.ai.h2o.securestore.v1B\x12SecretServiceProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.secret_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\022SecretServiceProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_CREATESECRETREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATESECRETREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\033\022\031securestore.h2o.ai/Secret'
  _globals['_CREATESECRETREQUEST'].fields_by_name['secret']._loaded_options = None
  _globals['_CREATESECRETREQUEST'].fields_by_name['secret']._serialized_options = b'\342A\001\002'
  _globals['_CREATESECRETREQUEST'].fields_by_name['secret_id']._loaded_options = None
  _globals['_CREATESECRETREQUEST'].fields_by_name['secret_id']._serialized_options = b'\342A\001\001'
  _globals['_GETSECRETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETSECRETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\033\n\031securestore.h2o.ai/Secret'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\033\022\031securestore.h2o.ai/Secret'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['show_deleted']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _globals['_DELETESECRETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETESECRETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\033\n\031securestore.h2o.ai/Secret'
  _globals['_UNDELETESECRETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UNDELETESECRETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\033\n\031securestore.h2o.ai/Secret'
  _globals['_SECRETSERVICE'].methods_by_name['CreateSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['CreateSecret']._serialized_options = b'\332A\027parent,secret,secret_id\202\323\344\223\002+\"!/v1/{parent=workspaces/*}/secrets:\006secret'
  _globals['_SECRETSERVICE'].methods_by_name['GetSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['GetSecret']._serialized_options = b'\332A\004name\202\323\344\223\002#\022!/v1/{name=workspaces/*/secrets/*}'
  _globals['_SECRETSERVICE'].methods_by_name['ListSecrets']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['ListSecrets']._serialized_options = b'\332A\006parent\202\323\344\223\002#\022!/v1/{parent=workspaces/*}/secrets'
  _globals['_SECRETSERVICE'].methods_by_name['DeleteSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['DeleteSecret']._serialized_options = b'\332A\004name\202\323\344\223\002#*!/v1/{name=workspaces/*/secrets/*}'
  _globals['_SECRETSERVICE'].methods_by_name['UndeleteSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['UndeleteSecret']._serialized_options = b'\202\323\344\223\002/\"*/v1/{name=workspaces/*/secrets/*}:undelete:\001*'
  _globals['_CREATESECRETREQUEST']._serialized_start=221
  _globals['_CREATESECRETREQUEST']._serialized_end=398
  _globals['_CREATESECRETRESPONSE']._serialized_start=400
  _globals['_CREATESECRETRESPONSE']._serialized_end=477
  _globals['_GETSECRETREQUEST']._serialized_start=479
  _globals['_GETSECRETREQUEST']._serialized_end=553
  _globals['_GETSECRETRESPONSE']._serialized_start=555
  _globals['_GETSECRETRESPONSE']._serialized_end=629
  _globals['_LISTSECRETSREQUEST']._serialized_start=632
  _globals['_LISTSECRETSREQUEST']._serialized_end=825
  _globals['_LISTSECRETSRESPONSE']._serialized_start=828
  _globals['_LISTSECRETSRESPONSE']._serialized_end=977
  _globals['_DELETESECRETREQUEST']._serialized_start=979
  _globals['_DELETESECRETREQUEST']._serialized_end=1056
  _globals['_DELETESECRETRESPONSE']._serialized_start=1058
  _globals['_DELETESECRETRESPONSE']._serialized_end=1135
  _globals['_UNDELETESECRETREQUEST']._serialized_start=1137
  _globals['_UNDELETESECRETREQUEST']._serialized_end=1216
  _globals['_UNDELETESECRETRESPONSE']._serialized_start=1218
  _globals['_UNDELETESECRETRESPONSE']._serialized_end=1297
  _globals['_SECRETSERVICE']._serialized_start=1300
  _globals['_SECRETSERVICE']._serialized_end=2123
# @@protoc_insertion_point(module_scope)
