# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/oauth_client_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from h2o_secure_store.gen.ai.h2o.securestore.v1 import oauth_client_pb2 as ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ai/h2o/securestore/v1/oauth_client_service.proto\x12\x15\x61i.h2o.securestore.v1\x1a(ai/h2o/securestore/v1/oauth_client.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/resource.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\x95\x01\n\x18\x43reateOAuthClientRequest\x12K\n\x0coauth_client\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.OAuthClientB\x04\xe2\x41\x01\x02R\x0boauthClient\x12,\n\x0foauth_client_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\roauthClientId\"b\n\x19\x43reateOAuthClientResponse\x12\x45\n\x0coauth_client\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.OAuthClientR\x0boauthClient\"T\n\x15GetOAuthClientRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1esecurestore.h2o.ai/OAuthClientR\x04name\"_\n\x16GetOAuthClientResponse\x12\x45\n\x0coauth_client\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.OAuthClientR\x0boauthClient\"a\n\x17ListOAuthClientsRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x8b\x01\n\x18ListOAuthClientsResponse\x12G\n\roauth_clients\x18\x01 \x03(\x0b\x32\".ai.h2o.securestore.v1.OAuthClientR\x0coauthClients\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xaa\x01\n\x18UpdateOAuthClientRequest\x12K\n\x0coauth_client\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.OAuthClientB\x04\xe2\x41\x01\x02R\x0boauthClient\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"b\n\x19UpdateOAuthClientResponse\x12\x45\n\x0coauth_client\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.OAuthClientR\x0boauthClient\"W\n\x18\x44\x65leteOAuthClientRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1esecurestore.h2o.ai/OAuthClientR\x04name\"\x1b\n\x19\x44\x65leteOAuthClientResponse\"\\\n\x1dInvalidateTokenSourcesRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1esecurestore.h2o.ai/OAuthClientR\x04name\" \n\x1eInvalidateTokenSourcesResponse2\xb8\x08\n\x12OAuthClientService\x12\xbd\x01\n\x11\x43reateOAuthClient\x12/.ai.h2o.securestore.v1.CreateOAuthClientRequest\x1a\x30.ai.h2o.securestore.v1.CreateOAuthClientResponse\"E\xda\x41\x1coauth_client,oauth_client_id\x82\xd3\xe4\x93\x02 \"\x10/v1/oauthClients:\x0coauth_client\x12\x97\x01\n\x0eGetOAuthClient\x12,.ai.h2o.securestore.v1.GetOAuthClientRequest\x1a-.ai.h2o.securestore.v1.GetOAuthClientResponse\"(\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/{name=oauthClients/*}\x12\x8d\x01\n\x10ListOAuthClients\x12..ai.h2o.securestore.v1.ListOAuthClientsRequest\x1a/.ai.h2o.securestore.v1.ListOAuthClientsResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/oauthClients\x12\xcf\x01\n\x11UpdateOAuthClient\x12/.ai.h2o.securestore.v1.UpdateOAuthClientRequest\x1a\x30.ai.h2o.securestore.v1.UpdateOAuthClientResponse\"W\xda\x41\x18oauth_client,update_mask\x82\xd3\xe4\x93\x02\x36\x32&/v1/{oauth_client.name=oauthClients/*}:\x0coauth_client\x12\xa0\x01\n\x11\x44\x65leteOAuthClient\x12/.ai.h2o.securestore.v1.DeleteOAuthClientRequest\x1a\x30.ai.h2o.securestore.v1.DeleteOAuthClientResponse\"(\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1b*\x19/v1/{name=oauthClients/*}\x12\xc2\x01\n\x16InvalidateTokenSources\x12\x34.ai.h2o.securestore.v1.InvalidateTokenSourcesRequest\x1a\x35.ai.h2o.securestore.v1.InvalidateTokenSourcesResponse\";\x82\xd3\xe4\x93\x02\x35\"0/v1/{name=oauthClients/*}:invalidateTokenSources:\x01*B\xf2\x01\n\x19\x63om.ai.h2o.securestore.v1B\x17OauthClientServiceProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.oauth_client_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\027OauthClientServiceProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client']._serialized_options = b'\342A\001\002'
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._serialized_options = b'\342A\001\001'
  _globals['_GETOAUTHCLIENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETOAUTHCLIENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036securestore.h2o.ai/OAuthClient'
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client']._loaded_options = None
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _globals['_DELETEOAUTHCLIENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEOAUTHCLIENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036securestore.h2o.ai/OAuthClient'
  _globals['_INVALIDATETOKENSOURCESREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_INVALIDATETOKENSOURCESREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036securestore.h2o.ai/OAuthClient'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['CreateOAuthClient']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['CreateOAuthClient']._serialized_options = b'\332A\034oauth_client,oauth_client_id\202\323\344\223\002 \"\020/v1/oauthClients:\014oauth_client'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['GetOAuthClient']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['GetOAuthClient']._serialized_options = b'\332A\004name\202\323\344\223\002\033\022\031/v1/{name=oauthClients/*}'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['ListOAuthClients']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['ListOAuthClients']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/oauthClients'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['UpdateOAuthClient']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['UpdateOAuthClient']._serialized_options = b'\332A\030oauth_client,update_mask\202\323\344\223\00262&/v1/{oauth_client.name=oauthClients/*}:\014oauth_client'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['DeleteOAuthClient']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['DeleteOAuthClient']._serialized_options = b'\332A\004name\202\323\344\223\002\033*\031/v1/{name=oauthClients/*}'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['InvalidateTokenSources']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['InvalidateTokenSources']._serialized_options = b'\202\323\344\223\0025\"0/v1/{name=oauthClients/*}:invalidateTokenSources:\001*'
  _globals['_CREATEOAUTHCLIENTREQUEST']._serialized_start=267
  _globals['_CREATEOAUTHCLIENTREQUEST']._serialized_end=416
  _globals['_CREATEOAUTHCLIENTRESPONSE']._serialized_start=418
  _globals['_CREATEOAUTHCLIENTRESPONSE']._serialized_end=516
  _globals['_GETOAUTHCLIENTREQUEST']._serialized_start=518
  _globals['_GETOAUTHCLIENTREQUEST']._serialized_end=602
  _globals['_GETOAUTHCLIENTRESPONSE']._serialized_start=604
  _globals['_GETOAUTHCLIENTRESPONSE']._serialized_end=699
  _globals['_LISTOAUTHCLIENTSREQUEST']._serialized_start=701
  _globals['_LISTOAUTHCLIENTSREQUEST']._serialized_end=798
  _globals['_LISTOAUTHCLIENTSRESPONSE']._serialized_start=801
  _globals['_LISTOAUTHCLIENTSRESPONSE']._serialized_end=940
  _globals['_UPDATEOAUTHCLIENTREQUEST']._serialized_start=943
  _globals['_UPDATEOAUTHCLIENTREQUEST']._serialized_end=1113
  _globals['_UPDATEOAUTHCLIENTRESPONSE']._serialized_start=1115
  _globals['_UPDATEOAUTHCLIENTRESPONSE']._serialized_end=1213
  _globals['_DELETEOAUTHCLIENTREQUEST']._serialized_start=1215
  _globals['_DELETEOAUTHCLIENTREQUEST']._serialized_end=1302
  _globals['_DELETEOAUTHCLIENTRESPONSE']._serialized_start=1304
  _globals['_DELETEOAUTHCLIENTRESPONSE']._serialized_end=1331
  _globals['_INVALIDATETOKENSOURCESREQUEST']._serialized_start=1333
  _globals['_INVALIDATETOKENSOURCESREQUEST']._serialized_end=1425
  _globals['_INVALIDATETOKENSOURCESRESPONSE']._serialized_start=1427
  _globals['_INVALIDATETOKENSOURCESRESPONSE']._serialized_end=1459
  _globals['_OAUTHCLIENTSERVICE']._serialized_start=1462
  _globals['_OAUTHCLIENTSERVICE']._serialized_end=2542
# @@protoc_insertion_point(module_scope)
