# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/secret.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ai/h2o/securestore/v1/secret.proto\x12\x15\x61i.h2o.securestore.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8f\x06\n\x06Secret\x12\x19\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x08\x03R\x04name\x12?\n\x05state\x18\x02 \x01(\x0e\x32#.ai.h2o.securestore.v1.Secret.StateB\x04\xe2\x41\x01\x03R\x05state\x12\x1e\n\x07\x63reator\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x07\x63reator\x12\x1f\n\x07\x64\x65leter\x18\x04 \x01(\tB\x05\xe2\x41\x02\x01\x03R\x07\x64\x65leter\x12\x41\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12G\n\x0b\x64\x65lete_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x01\x03H\x00R\ndeleteTime\x88\x01\x01\x12\x45\n\npurge_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x01\x03H\x01R\tpurgeTime\x88\x01\x01\x12\x16\n\x03uid\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12V\n\x0b\x61nnotations\x18\t \x03(\x0b\x32..ai.h2o.securestore.v1.Secret.AnnotationsEntryB\x04\xe2\x41\x01\x01R\x0b\x61nnotations\x12\'\n\x0c\x64isplay_name\x18\n \x01(\tB\x04\xe2\x41\x01\x01R\x0b\x64isplayName\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"C\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x10\n\x0cSTATE_ACTIVE\x10\x01\x12\x11\n\rSTATE_DELETED\x10\x02:X\xea\x41U\n\x19securestore.h2o.ai/Secret\x12\'workspaces/{workspace}/secrets/{secret}*\x07secrets2\x06secretB\x0e\n\x0c_delete_timeB\r\n\x0b_purge_timeB\xe6\x01\n\x19\x63om.ai.h2o.securestore.v1B\x0bSecretProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.secret_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\013SecretProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_SECRET_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_SECRET_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_SECRET'].fields_by_name['name']._loaded_options = None
  _globals['_SECRET'].fields_by_name['name']._serialized_options = b'\342A\002\010\003'
  _globals['_SECRET'].fields_by_name['state']._loaded_options = None
  _globals['_SECRET'].fields_by_name['state']._serialized_options = b'\342A\001\003'
  _globals['_SECRET'].fields_by_name['creator']._loaded_options = None
  _globals['_SECRET'].fields_by_name['creator']._serialized_options = b'\342A\001\003'
  _globals['_SECRET'].fields_by_name['deleter']._loaded_options = None
  _globals['_SECRET'].fields_by_name['deleter']._serialized_options = b'\342A\002\001\003'
  _globals['_SECRET'].fields_by_name['create_time']._loaded_options = None
  _globals['_SECRET'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_SECRET'].fields_by_name['delete_time']._loaded_options = None
  _globals['_SECRET'].fields_by_name['delete_time']._serialized_options = b'\342A\002\001\003'
  _globals['_SECRET'].fields_by_name['purge_time']._loaded_options = None
  _globals['_SECRET'].fields_by_name['purge_time']._serialized_options = b'\342A\002\001\003'
  _globals['_SECRET'].fields_by_name['uid']._loaded_options = None
  _globals['_SECRET'].fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _globals['_SECRET'].fields_by_name['annotations']._loaded_options = None
  _globals['_SECRET'].fields_by_name['annotations']._serialized_options = b'\342A\001\001'
  _globals['_SECRET'].fields_by_name['display_name']._loaded_options = None
  _globals['_SECRET'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_SECRET']._loaded_options = None
  _globals['_SECRET']._serialized_options = b'\352AU\n\031securestore.h2o.ai/Secret\022\'workspaces/{workspace}/secrets/{secret}*\007secrets2\006secret'
  _globals['_SECRET']._serialized_start=155
  _globals['_SECRET']._serialized_end=938
  _globals['_SECRET_ANNOTATIONSENTRY']._serialized_start=686
  _globals['_SECRET_ANNOTATIONSENTRY']._serialized_end=748
  _globals['_SECRET_STATE']._serialized_start=750
  _globals['_SECRET_STATE']._serialized_end=817
# @@protoc_insertion_point(module_scope)
