# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/secret_version_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from h2o_secure_store.gen.ai.h2o.securestore.v1 import secret_version_pb2 as ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2ai/h2o/securestore/v1/secret_version_service.proto\x12\x15\x61i.h2o.securestore.v1\x1a*ai/h2o/securestore/v1/secret_version.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/resource.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\"\xb2\x01\n\x1a\x43reateSecretVersionRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\x12 securestore.h2o.ai/SecretVersionR\x06parent\x12Q\n\x0esecret_version\x18\x02 \x01(\x0b\x32$.ai.h2o.securestore.v1.SecretVersionB\x04\xe2\x41\x01\x02R\rsecretVersion\"j\n\x1b\x43reateSecretVersionResponse\x12K\n\x0esecret_version\x18\x01 \x01(\x0b\x32$.ai.h2o.securestore.v1.SecretVersionR\rsecretVersion\"X\n\x17GetSecretVersionRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n securestore.h2o.ai/SecretVersionR\x04name\"g\n\x18GetSecretVersionResponse\x12K\n\x0esecret_version\x18\x01 \x01(\x0b\x32$.ai.h2o.securestore.v1.SecretVersionR\rsecretVersion\"\xa6\x01\n\x19ListSecretVersionsRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\x12 securestore.h2o.ai/SecretVersionR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\xb2\x01\n\x1aListSecretVersionsResponse\x12M\n\x0fsecret_versions\x18\x01 \x03(\x0b\x32$.ai.h2o.securestore.v1.SecretVersionR\x0esecretVersions\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"`\n\x1fRevealSecretVersionValueRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n securestore.h2o.ai/SecretVersionR\x04name\"L\n RevealSecretVersionValueResponse\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value2\xb1\x06\n\x14SecretVersionService\x12\xda\x01\n\x13\x43reateSecretVersion\x12\x31.ai.h2o.securestore.v1.CreateSecretVersionRequest\x1a\x32.ai.h2o.securestore.v1.CreateSecretVersionResponse\"\\\xda\x41\x15parent,secret_version\x82\xd3\xe4\x93\x02>\",/v1/{parent=workspaces/*/secrets/*}/versions:\x0esecret_version\x12\xb0\x01\n\x10GetSecretVersion\x12..ai.h2o.securestore.v1.GetSecretVersionRequest\x1a/.ai.h2o.securestore.v1.GetSecretVersionResponse\";\xda\x41\x04name\x82\xd3\xe4\x93\x02.\x12,/v1/{name=workspaces/*/secrets/*/versions/*}\x12\xb8\x01\n\x12ListSecretVersions\x12\x30.ai.h2o.securestore.v1.ListSecretVersionsRequest\x1a\x31.ai.h2o.securestore.v1.ListSecretVersionsResponse\"=\xda\x41\x06parent\x82\xd3\xe4\x93\x02.\x12,/v1/{parent=workspaces/*/secrets/*}/versions\x12\xcd\x01\n\x18RevealSecretVersionValue\x12\x36.ai.h2o.securestore.v1.RevealSecretVersionValueRequest\x1a\x37.ai.h2o.securestore.v1.RevealSecretVersionValueResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/v1/{name=workspaces/*/secrets/*/versions/*}:revealValueB\xf4\x01\n\x19\x63om.ai.h2o.securestore.v1B\x19SecretVersionServiceProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.secret_version_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\031SecretVersionServiceProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_CREATESECRETVERSIONREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATESECRETVERSIONREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\022 securestore.h2o.ai/SecretVersion'
  _globals['_CREATESECRETVERSIONREQUEST'].fields_by_name['secret_version']._loaded_options = None
  _globals['_CREATESECRETVERSIONREQUEST'].fields_by_name['secret_version']._serialized_options = b'\342A\001\002'
  _globals['_GETSECRETVERSIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETSECRETVERSIONREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n securestore.h2o.ai/SecretVersion'
  _globals['_LISTSECRETVERSIONSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTSECRETVERSIONSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\022 securestore.h2o.ai/SecretVersion'
  _globals['_LISTSECRETVERSIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSECRETVERSIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTSECRETVERSIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSECRETVERSIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_REVEALSECRETVERSIONVALUEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REVEALSECRETVERSIONVALUEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n securestore.h2o.ai/SecretVersion'
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['CreateSecretVersion']._loaded_options = None
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['CreateSecretVersion']._serialized_options = b'\332A\025parent,secret_version\202\323\344\223\002>\",/v1/{parent=workspaces/*/secrets/*}/versions:\016secret_version'
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['GetSecretVersion']._loaded_options = None
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['GetSecretVersion']._serialized_options = b'\332A\004name\202\323\344\223\002.\022,/v1/{name=workspaces/*/secrets/*/versions/*}'
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['ListSecretVersions']._loaded_options = None
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['ListSecretVersions']._serialized_options = b'\332A\006parent\202\323\344\223\002.\022,/v1/{parent=workspaces/*/secrets/*}/versions'
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['RevealSecretVersionValue']._loaded_options = None
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['RevealSecretVersionValue']._serialized_options = b'\202\323\344\223\002:\0228/v1/{name=workspaces/*/secrets/*/versions/*}:revealValue'
  _globals['_CREATESECRETVERSIONREQUEST']._serialized_start=237
  _globals['_CREATESECRETVERSIONREQUEST']._serialized_end=415
  _globals['_CREATESECRETVERSIONRESPONSE']._serialized_start=417
  _globals['_CREATESECRETVERSIONRESPONSE']._serialized_end=523
  _globals['_GETSECRETVERSIONREQUEST']._serialized_start=525
  _globals['_GETSECRETVERSIONREQUEST']._serialized_end=613
  _globals['_GETSECRETVERSIONRESPONSE']._serialized_start=615
  _globals['_GETSECRETVERSIONRESPONSE']._serialized_end=718
  _globals['_LISTSECRETVERSIONSREQUEST']._serialized_start=721
  _globals['_LISTSECRETVERSIONSREQUEST']._serialized_end=887
  _globals['_LISTSECRETVERSIONSRESPONSE']._serialized_start=890
  _globals['_LISTSECRETVERSIONSRESPONSE']._serialized_end=1068
  _globals['_REVEALSECRETVERSIONVALUEREQUEST']._serialized_start=1070
  _globals['_REVEALSECRETVERSIONVALUEREQUEST']._serialized_end=1166
  _globals['_REVEALSECRETVERSIONVALUERESPONSE']._serialized_start=1168
  _globals['_REVEALSECRETVERSIONVALUERESPONSE']._serialized_end=1244
  _globals['_SECRETVERSIONSERVICE']._serialized_start=1247
  _globals['_SECRETVERSIONSERVICE']._serialized_end=2064
# @@protoc_insertion_point(module_scope)
