# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/oauth_client.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ai/h2o/securestore/v1/oauth_client.proto\x12\x15\x61i.h2o.securestore.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xed\x06\n\x0bOAuthClient\x12\x19\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x08\x03R\x04name\x12\'\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0b\x64isplayName\x12\x1d\n\x06issuer\x18\x03 \x01(\tB\x05\xe2\x41\x02\x02\x05R\x06issuer\x12\"\n\tclient_id\x18\x04 \x01(\tB\x05\xe2\x41\x02\x02\x05R\x08\x63lientId\x12*\n\rclient_secret\x18\x05 \x01(\tB\x05\xe2\x41\x02\x01\x04R\x0c\x63lientSecret\x12\x30\n\x11\x63lient_secret_set\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x03R\x0f\x63lientSecretSet\x12<\n\x16\x61uthorization_endpoint\x18\x07 \x01(\tB\x05\xe2\x41\x02\x01\x07R\x15\x61uthorizationEndpoint\x12,\n\x0etoken_endpoint\x18\x08 \x01(\tB\x05\xe2\x41\x02\x01\x07R\rtokenEndpoint\x12\'\n\x0c\x65xtra_scopes\x18\t \x03(\tB\x04\xe2\x41\x01\x01R\x0b\x65xtraScopes\x12/\n\x10refresh_disabled\x18\n \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0frefreshDisabled\x12\x39\n\x15login_principal_claim\x18\x0b \x01(\tB\x05\xe2\x41\x02\x01\x07R\x13loginPrincipalClaim\x12\'\n\x0c\x63\x61llback_uri\x18\x0c \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x63\x61llbackUri\x12\x1e\n\x07\x63reator\x18\r \x01(\tB\x04\xe2\x41\x01\x03R\x07\x63reator\x12\x1f\n\x07updater\x18\x0e \x01(\tB\x05\xe2\x41\x02\x01\x03R\x07updater\x12\x41\n\x0b\x63reate_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12G\n\x0bupdate_time\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x01\x03H\x00R\nupdateTime\x88\x01\x01\x12\x16\n\x03uid\x18\x11 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid:Z\xea\x41W\n\x1esecurestore.h2o.ai/OAuthClient\x12\x1aoauthClients/{oauthClient}*\x0coauthClients2\x0boauthClientB\x0e\n\x0c_update_timeB\xeb\x01\n\x19\x63om.ai.h2o.securestore.v1B\x10OauthClientProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.oauth_client_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\020OauthClientProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_OAUTHCLIENT'].fields_by_name['name']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['name']._serialized_options = b'\342A\002\010\003'
  _globals['_OAUTHCLIENT'].fields_by_name['display_name']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_OAUTHCLIENT'].fields_by_name['issuer']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['issuer']._serialized_options = b'\342A\002\002\005'
  _globals['_OAUTHCLIENT'].fields_by_name['client_id']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['client_id']._serialized_options = b'\342A\002\002\005'
  _globals['_OAUTHCLIENT'].fields_by_name['client_secret']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['client_secret']._serialized_options = b'\342A\002\001\004'
  _globals['_OAUTHCLIENT'].fields_by_name['client_secret_set']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['client_secret_set']._serialized_options = b'\342A\001\003'
  _globals['_OAUTHCLIENT'].fields_by_name['authorization_endpoint']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['authorization_endpoint']._serialized_options = b'\342A\002\001\007'
  _globals['_OAUTHCLIENT'].fields_by_name['token_endpoint']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['token_endpoint']._serialized_options = b'\342A\002\001\007'
  _globals['_OAUTHCLIENT'].fields_by_name['extra_scopes']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['extra_scopes']._serialized_options = b'\342A\001\001'
  _globals['_OAUTHCLIENT'].fields_by_name['refresh_disabled']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['refresh_disabled']._serialized_options = b'\342A\001\001'
  _globals['_OAUTHCLIENT'].fields_by_name['login_principal_claim']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['login_principal_claim']._serialized_options = b'\342A\002\001\007'
  _globals['_OAUTHCLIENT'].fields_by_name['callback_uri']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['callback_uri']._serialized_options = b'\342A\001\003'
  _globals['_OAUTHCLIENT'].fields_by_name['creator']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['creator']._serialized_options = b'\342A\001\003'
  _globals['_OAUTHCLIENT'].fields_by_name['updater']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['updater']._serialized_options = b'\342A\002\001\003'
  _globals['_OAUTHCLIENT'].fields_by_name['create_time']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_OAUTHCLIENT'].fields_by_name['update_time']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['update_time']._serialized_options = b'\342A\002\001\003'
  _globals['_OAUTHCLIENT'].fields_by_name['uid']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _globals['_OAUTHCLIENT']._loaded_options = None
  _globals['_OAUTHCLIENT']._serialized_options = b'\352AW\n\036securestore.h2o.ai/OAuthClient\022\032oauthClients/{oauthClient}*\014oauthClients2\013oauthClient'
  _globals['_OAUTHCLIENT']._serialized_start=161
  _globals['_OAUTHCLIENT']._serialized_end=1038
# @@protoc_insertion_point(module_scope)
