# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/token_source_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from h2o_secure_store.gen.ai.h2o.securestore.v1 import token_source_pb2 as ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ai/h2o/securestore/v1/token_source_service.proto\x12\x15\x61i.h2o.securestore.v1\x1a(ai/h2o/securestore/v1/token_source.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/resource.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\"\xd6\x01\n\x18\x43reateTokenSourceRequest\x12?\n\x06parent\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \x12\x1esecurestore.h2o.ai/OAuthClientR\x06parent\x12K\n\x0ctoken_source\x18\x02 \x01(\x0b\x32\".ai.h2o.securestore.v1.TokenSourceB\x04\xe2\x41\x01\x02R\x0btokenSource\x12,\n\x0ftoken_source_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\rtokenSourceId\"b\n\x19\x43reateTokenSourceResponse\x12\x45\n\x0ctoken_source\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.TokenSourceR\x0btokenSource\"T\n\x15GetTokenSourceRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1esecurestore.h2o.ai/TokenSourceR\x04name\"_\n\x16GetTokenSourceResponse\x12\x45\n\x0ctoken_source\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.TokenSourceR\x0btokenSource\"\xa2\x01\n\x17ListTokenSourcesRequest\x12?\n\x06parent\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \x12\x1esecurestore.h2o.ai/TokenSourceR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x8b\x01\n\x18ListTokenSourcesResponse\x12G\n\rtoken_sources\x18\x01 \x03(\x0b\x32\".ai.h2o.securestore.v1.TokenSourceR\x0ctokenSources\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"W\n\x18\x44\x65leteTokenSourceRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1esecurestore.h2o.ai/TokenSourceR\x04name\"\x1b\n\x19\x44\x65leteTokenSourceResponse2\xff\x05\n\x12TokenSourceService\x12\xdc\x01\n\x11\x43reateTokenSource\x12/.ai.h2o.securestore.v1.CreateTokenSourceRequest\x1a\x30.ai.h2o.securestore.v1.CreateTokenSourceResponse\"d\xda\x41#parent,token_source,token_source_id\x82\xd3\xe4\x93\x02\x38\"(/v1/{parent=oauthClients/*}/tokenSources:\x0ctoken_source\x12\xa6\x01\n\x0eGetTokenSource\x12,.ai.h2o.securestore.v1.GetTokenSourceRequest\x1a-.ai.h2o.securestore.v1.GetTokenSourceResponse\"7\xda\x41\x04name\x82\xd3\xe4\x93\x02*\x12(/v1/{name=oauthClients/*/tokenSources/*}\x12\xae\x01\n\x10ListTokenSources\x12..ai.h2o.securestore.v1.ListTokenSourcesRequest\x1a/.ai.h2o.securestore.v1.ListTokenSourcesResponse\"9\xda\x41\x06parent\x82\xd3\xe4\x93\x02*\x12(/v1/{parent=oauthClients/*}/tokenSources\x12\xaf\x01\n\x11\x44\x65leteTokenSource\x12/.ai.h2o.securestore.v1.DeleteTokenSourceRequest\x1a\x30.ai.h2o.securestore.v1.DeleteTokenSourceResponse\"7\xda\x41\x04name\x82\xd3\xe4\x93\x02**(/v1/{name=oauthClients/*/tokenSources/*}B\xf2\x01\n\x19\x63om.ai.h2o.securestore.v1B\x17TokenSourceServiceProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.token_source_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\027TokenSourceServiceProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_CREATETOKENSOURCEREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATETOKENSOURCEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A \022\036securestore.h2o.ai/OAuthClient'
  _globals['_CREATETOKENSOURCEREQUEST'].fields_by_name['token_source']._loaded_options = None
  _globals['_CREATETOKENSOURCEREQUEST'].fields_by_name['token_source']._serialized_options = b'\342A\001\002'
  _globals['_CREATETOKENSOURCEREQUEST'].fields_by_name['token_source_id']._loaded_options = None
  _globals['_CREATETOKENSOURCEREQUEST'].fields_by_name['token_source_id']._serialized_options = b'\342A\001\001'
  _globals['_GETTOKENSOURCEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETTOKENSOURCEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036securestore.h2o.ai/TokenSource'
  _globals['_LISTTOKENSOURCESREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTTOKENSOURCESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A \022\036securestore.h2o.ai/TokenSource'
  _globals['_LISTTOKENSOURCESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTTOKENSOURCESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTTOKENSOURCESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTTOKENSOURCESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_DELETETOKENSOURCEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETETOKENSOURCEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036securestore.h2o.ai/TokenSource'
  _globals['_TOKENSOURCESERVICE'].methods_by_name['CreateTokenSource']._loaded_options = None
  _globals['_TOKENSOURCESERVICE'].methods_by_name['CreateTokenSource']._serialized_options = b'\332A#parent,token_source,token_source_id\202\323\344\223\0028\"(/v1/{parent=oauthClients/*}/tokenSources:\014token_source'
  _globals['_TOKENSOURCESERVICE'].methods_by_name['GetTokenSource']._loaded_options = None
  _globals['_TOKENSOURCESERVICE'].methods_by_name['GetTokenSource']._serialized_options = b'\332A\004name\202\323\344\223\002*\022(/v1/{name=oauthClients/*/tokenSources/*}'
  _globals['_TOKENSOURCESERVICE'].methods_by_name['ListTokenSources']._loaded_options = None
  _globals['_TOKENSOURCESERVICE'].methods_by_name['ListTokenSources']._serialized_options = b'\332A\006parent\202\323\344\223\002*\022(/v1/{parent=oauthClients/*}/tokenSources'
  _globals['_TOKENSOURCESERVICE'].methods_by_name['DeleteTokenSource']._loaded_options = None
  _globals['_TOKENSOURCESERVICE'].methods_by_name['DeleteTokenSource']._serialized_options = b'\332A\004name\202\323\344\223\002**(/v1/{name=oauthClients/*/tokenSources/*}'
  _globals['_CREATETOKENSOURCEREQUEST']._serialized_start=233
  _globals['_CREATETOKENSOURCEREQUEST']._serialized_end=447
  _globals['_CREATETOKENSOURCERESPONSE']._serialized_start=449
  _globals['_CREATETOKENSOURCERESPONSE']._serialized_end=547
  _globals['_GETTOKENSOURCEREQUEST']._serialized_start=549
  _globals['_GETTOKENSOURCEREQUEST']._serialized_end=633
  _globals['_GETTOKENSOURCERESPONSE']._serialized_start=635
  _globals['_GETTOKENSOURCERESPONSE']._serialized_end=730
  _globals['_LISTTOKENSOURCESREQUEST']._serialized_start=733
  _globals['_LISTTOKENSOURCESREQUEST']._serialized_end=895
  _globals['_LISTTOKENSOURCESRESPONSE']._serialized_start=898
  _globals['_LISTTOKENSOURCESRESPONSE']._serialized_end=1037
  _globals['_DELETETOKENSOURCEREQUEST']._serialized_start=1039
  _globals['_DELETETOKENSOURCEREQUEST']._serialized_end=1126
  _globals['_DELETETOKENSOURCERESPONSE']._serialized_start=1128
  _globals['_DELETETOKENSOURCERESPONSE']._serialized_end=1155
  _globals['_TOKENSOURCESERVICE']._serialized_start=1158
  _globals['_TOKENSOURCESERVICE']._serialized_end=1925
# @@protoc_insertion_point(module_scope)
