# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/secret_version.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ai/h2o/securestore/v1/secret_version.proto\x12\x15\x61i.h2o.securestore.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc5\x02\n\rSecretVersion\x12\x19\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x08\x03R\x04name\x12\x1b\n\x05value\x18\x02 \x01(\x0c\x42\x05\xe2\x41\x02\x02\x04R\x05value\x12\x1e\n\x07\x63reator\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x07\x63reator\x12\x41\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x16\n\x03uid\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid:\x80\x01\xea\x41}\n securestore.h2o.ai/SecretVersion\x12:workspaces/{workspace}/secrets/{secret}/versions/{version}*\x0esecretVersions2\rsecretVersionB\xed\x01\n\x19\x63om.ai.h2o.securestore.v1B\x12SecretVersionProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.secret_version_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\022SecretVersionProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_SECRETVERSION'].fields_by_name['name']._loaded_options = None
  _globals['_SECRETVERSION'].fields_by_name['name']._serialized_options = b'\342A\002\010\003'
  _globals['_SECRETVERSION'].fields_by_name['value']._loaded_options = None
  _globals['_SECRETVERSION'].fields_by_name['value']._serialized_options = b'\342A\002\002\004'
  _globals['_SECRETVERSION'].fields_by_name['creator']._loaded_options = None
  _globals['_SECRETVERSION'].fields_by_name['creator']._serialized_options = b'\342A\001\003'
  _globals['_SECRETVERSION'].fields_by_name['create_time']._loaded_options = None
  _globals['_SECRETVERSION'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_SECRETVERSION'].fields_by_name['uid']._loaded_options = None
  _globals['_SECRETVERSION'].fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _globals['_SECRETVERSION']._loaded_options = None
  _globals['_SECRETVERSION']._serialized_options = b'\352A}\n securestore.h2o.ai/SecretVersion\022:workspaces/{workspace}/secrets/{secret}/versions/{version}*\016secretVersions2\rsecretVersion'
  _globals['_SECRETVERSION']._serialized_start=163
  _globals['_SECRETVERSION']._serialized_end=488
# @@protoc_insertion_point(module_scope)
