# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/token_source.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ai/h2o/securestore/v1/token_source.proto\x12\x15\x61i.h2o.securestore.v1\x1a\x19google/api/resource.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x92\x06\n\x0bTokenSource\x12\x19\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x08\x03R\x04name\x12(\n\x0credirect_uri\x18\x02 \x01(\tB\x05\xe2\x41\x02\x01\x05R\x0bredirectUri\x12!\n\tlogin_uri\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x08loginUri\x12+\n\x0elogin_required\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x03R\rloginRequired\x12(\n\x0c\x61\x63\x63\x65ss_token\x18\x05 \x01(\tB\x05\xe2\x41\x02\x01\x03R\x0b\x61\x63\x63\x65ssToken\x12\x45\n\nissue_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x01\x03H\x00R\tissueTime\x88\x01\x01\x12\x46\n\x0b\x65xpire_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03H\x01R\nexpireTime\x88\x01\x01\x12\x1e\n\x07subject\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03R\x07subject\x12.\n\x0flogin_principal\x18\t \x01(\tB\x05\xe2\x41\x02\x01\x03R\x0eloginPrincipal\x12\x1e\n\x07\x63reator\x18\n \x01(\tB\x04\xe2\x41\x01\x03R\x07\x63reator\x12\x41\n\x0b\x63reate_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x45\n\nlogin_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x01\x03H\x02R\tloginTime\x88\x01\x01\x12\x16\n\x03uid\x18\r \x01(\tB\x04\xe2\x41\x01\x03R\x03uid:u\xea\x41r\n\x1esecurestore.h2o.ai/TokenSource\x12\x35oauthClients/{oauthClient}/tokenSources/{tokenSource}*\x0ctokenSources2\x0btokenSourceB\r\n\x0b_issue_timeB\x0e\n\x0c_expire_timeB\r\n\x0b_login_timeB\xeb\x01\n\x19\x63om.ai.h2o.securestore.v1B\x10TokenSourceProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.token_source_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\020TokenSourceProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_TOKENSOURCE'].fields_by_name['name']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['name']._serialized_options = b'\342A\002\010\003'
  _globals['_TOKENSOURCE'].fields_by_name['redirect_uri']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['redirect_uri']._serialized_options = b'\342A\002\001\005'
  _globals['_TOKENSOURCE'].fields_by_name['login_uri']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['login_uri']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['login_required']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['login_required']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['access_token']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['access_token']._serialized_options = b'\342A\002\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['issue_time']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['issue_time']._serialized_options = b'\342A\002\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['expire_time']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['expire_time']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['subject']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['subject']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['login_principal']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['login_principal']._serialized_options = b'\342A\002\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['creator']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['creator']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['create_time']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['login_time']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['login_time']._serialized_options = b'\342A\002\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['uid']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE']._loaded_options = None
  _globals['_TOKENSOURCE']._serialized_options = b'\352Ar\n\036securestore.h2o.ai/TokenSource\0225oauthClients/{oauthClient}/tokenSources/{tokenSource}*\014tokenSources2\013tokenSource'
  _globals['_TOKENSOURCE']._serialized_start=161
  _globals['_TOKENSOURCE']._serialized_end=947
# @@protoc_insertion_point(module_scope)
